@@ -2,7 +2,8 @@
 
 #' @title Maximum pseudo-likelihood estimation by wrapped pseudo-likelihoods
 #'
-#' @description Maximum pseudo-likelihood using the Euler and Shoji--Ozaki pseudo-likelihoods.
+#' @description Maximum pseudo-likelihood using the Euler and Shoji--Ozaki
+#' pseudo-likelihoods.
 #'
 #' @param data a matrix of dimension \code{c(n, p)}.
 #' @param delta discretization step.
@@ -10,11 +11,18 @@
 #' @inheritParams mleOptimWrapper
 #' @param ... further parameters passed to \code{\link{mleOptimWrapper}}.
 #' @return Output from \code{\link{mleOptimWrapper}}.
-#' @details See Section 3.2 in García-Portugués et al. (2019) for details. \code{"SO2"} implements Shoji and Ozai (1998)'s expansion with for \code{p = 1}. \code{"SO"} is the same expansion, for arbitrary \code{p}, but considering null second derivatives.
+#' @details See Section 3.2 in García-Portugués et al. (2019) for details.
+#' \code{"SO2"} implements Shoji and Ozai (1998)'s expansion with for
+#' \code{p = 1}. \code{"SO"} is the same expansion, for arbitrary \code{p},
+#' but considering null second derivatives.
 #' @references
-#' García-Portugués, E., Sørensen, M., Mardia, K. V. and Hamelryck, T. (2019) Langevin diffusions on the torus: estimation and applications. \emph{Statistics and Computing}, 29(2):1--22. \doi{10.1007/s11222-017-9790-2}
+#' García-Portugués, E., Sørensen, M., Mardia, K. V. and Hamelryck, T. (2019)
+#' Langevin diffusions on the torus: estimation and applications.
+#' \emph{Statistics and Computing}, 29(2):1--22. \doi{10.1007/s11222-017-9790-2}
 #'
-#' Shoji, I. and Ozaki, T. (1998) A statistical method of estimation and simulation for systems of stochastic differential equations. \emph{Biometrika}, 85(1):240--243. \doi{10.1093/biomet/85.1.240}
+#' Shoji, I. and Ozaki, T. (1998) A statistical method of estimation and
+#' simulation for systems of stochastic differential equations.
+#' \emph{Biometrika}, 85(1):240--243. \doi{10.1093/biomet/85.1.240}
 #' @examples
 #' \donttest{
 #' # Example in 1D
@@ -74,7 +82,8 @@
 #'   cbind(res[1:l, ] - res[(l + 1):(2 * l), ],
 #'         res[2 * l + 1:l, ] - res[2 * l + (l + 1):(2 * l), ]) / (2 * h)
 #' }
-#' sigma2 <- function(x, pars) matrix(pars[6:7]^2, nrow = length(x) / 2L, ncol = 2)
+#' sigma2 <- function(x, pars) matrix(pars[6:7]^2, nrow = length(x) / 2L,
+#'                                    ncol = 2)
 #' lower <- c(0.01, 0.01, -25, -pi, -pi, 0.01, 0.01)
 #' upper <- c(25, 25, 25, pi, pi, 25, 25)
 #' psMle(data = samp, delta = delta, method = "E", b = b, sigma2 = sigma2,
@@ -124,7 +133,7 @@ psMle <- function(data, delta, method = c("E", "SO", "SO2"), b, jac.b, sigma2,
   # twokpi to avoid recomputing
   if (!vmApprox) {
 
-    if (method == "SO" & p > 1) {
+    if (method == "SO" && p > 1) {
 
       twokpi <- as.matrix(do.call(what = expand.grid,
                                   args = rep(list(2 * pi * sK), p)))
@@ -155,15 +164,21 @@ psMle <- function(data, delta, method = c("E", "SO", "SO2"), b, jac.b, sigma2,
 
 #' @title Approximate MLE of the WN diffusion in 1D
 #'
-#' @description Approximate Maximum Likelihood Estimation (MLE) for the Wrapped Normal (WN) in 1D using the wrapped Ornstein--Uhlenbeck diffusion.
+#' @description Approximate Maximum Likelihood Estimation (MLE) for the Wrapped
+#' Normal (WN) in 1D using the wrapped Ornstein--Uhlenbeck diffusion.
 #'
 #' @inheritParams psMle
-#' @param alpha,mu,sigma if their values are provided, the likelihood function is optimized with respect to the rest of unspecified parameters. The number of elements in \code{start}, \code{lower} and \code{upper} has to be modified accordingly (see examples).
+#' @param alpha,mu,sigma if their values are provided, the likelihood function
+#' is optimized with respect to the rest of unspecified parameters. The number
+#' of elements in \code{start}, \code{lower} and \code{upper} has to be modified
+#' accordingly (see examples).
 #' @inheritParams safeSoftMax
 #' @return Output from \code{\link{mleOptimWrapper}}.
 #' @details See Section 3.3 in García-Portugués et al. (2019) for details.
 #' @references
-#' García-Portugués, E., Sørensen, M., Mardia, K. V. and Hamelryck, T. (2019) Langevin diffusions on the torus: estimation and applications. \emph{Statistics and Computing}, 29(2):1--22. \doi{10.1007/s11222-017-9790-2}
+#' García-Portugués, E., Sørensen, M., Mardia, K. V. and Hamelryck, T. (2019)
+#' Langevin diffusions on the torus: estimation and applications.
+#' \emph{Statistics and Computing}, 29(2):1--22. \doi{10.1007/s11222-017-9790-2}
 #' @examples
 #' alpha <- 0.5
 #' mu <- 0
@@ -187,7 +202,7 @@ approxMleWn1D <- function(data, delta, start, alpha = NA, mu = NA, sigma = NA,
   y <- data[-1]
   x <- data[-N]
 
-  # Specfied parameters
+  # Specified parameters
   specPars <- c(alpha, mu, sigma)
   indUnSpecPars <- is.na(specPars)
 
@@ -210,16 +225,22 @@ approxMleWn1D <- function(data, delta, start, alpha = NA, mu = NA, sigma = NA,
 
 #' @title Approximate MLE of the WN diffusion in 2D
 #'
-#' @description Approximate Maximum Likelihood Estimation (MLE) for the Wrapped Normal (WN) in 2D using the wrapped Ornstein--Uhlenbeck diffusion.
+#' @description Approximate Maximum Likelihood Estimation (MLE) for the Wrapped
+#' Normal (WN) in 2D using the wrapped Ornstein--Uhlenbeck diffusion.
 #'
 #' @inheritParams psMle
 #' @inheritParams approxMleWn1D
-#' @param alpha,mu,sigma,rho if their values are provided, the likelihood function is optimized with respect to the rest of unspecified parameters. The number of elements in \code{start}, \code{lower} and \code{upper} has to be modified accordingly (see examples).
+#' @param alpha,mu,sigma,rho if their values are provided, the likelihood
+#' function is optimized with respect to the rest of unspecified parameters.
+#' The number of elements in \code{start}, \code{lower} and \code{upper} has to
+#' be modified accordingly (see examples).
 #' @inheritParams safeSoftMax
 #' @return Output from \code{\link{mleOptimWrapper}}.
 #' @details See Section 3.3 in García-Portugués et al. (2019) for details.
 #' @references
-#' García-Portugués, E., Sørensen, M., Mardia, K. V. and Hamelryck, T. (2019) Langevin diffusions on the torus: estimation and applications. \emph{Statistics and Computing}, 29(2):1--22. \doi{10.1007/s11222-017-9790-2}
+#' García-Portugués, E., Sørensen, M., Mardia, K. V. and Hamelryck, T. (2019)
+#' Langevin diffusions on the torus: estimation and applications.
+#' \emph{Statistics and Computing}, 29(2):1--22. \doi{10.1007/s11222-017-9790-2}
 #' @examples
 #' alpha <- c(2, 2, -0.5)
 #' mu <- c(0, 0)
@@ -236,7 +257,8 @@ approxMleWn1D <- function(data, delta, start, alpha = NA, mu = NA, sigma = NA,
 #' @export
 approxMleWn2D <- function(data, delta, start, alpha = rep(NA, 3),
                           mu = rep(NA, 2), sigma = rep(NA, 2), rho = NA,
-                          lower = c(0.01, 0.01, -25, -pi, -pi, 0.01, 0.01, -0.99),
+                          lower = c(0.01, 0.01, -25, -pi, -pi, 0.01, 0.01,
+                                    -0.99),
                           upper = c(rep(25, 3), pi, pi, 25, 25, 0.99),
                           maxK = 2, ...) {
 
@@ -247,13 +269,12 @@ approxMleWn2D <- function(data, delta, start, alpha = rep(NA, 3),
 
   }
   N <- nrow(data)
-  p <- ncol(data)
 
   # Translate data
   y <- data[-1, ]
   x <- data[-N, ]
 
-  # Specfied parameters
+  # Specified parameters
   specPars <- c(alpha, mu, sigma, rho)
   indUnSpecPars <- is.na(specPars)
 
@@ -274,7 +295,7 @@ approxMleWn2D <- function(data, delta, start, alpha = rep(NA, 3),
     region <- function(pars) {
 
       # Test
-      prodDiagonal = 0.25 * (pars[8] * (pars[2] - pars[1]))^2 +
+      prodDiagonal <- 0.25 * (pars[8] * (pars[2] - pars[1]))^2 +
         alpha[1] * alpha[2] + pars[1] * pars[2]
       testPosDef <- prodDiagonal - pars[3]^2
       if (testPosDef < 0) {
@@ -313,17 +334,22 @@ approxMleWn2D <- function(data, delta, start, alpha = rep(NA, 3),
 #'
 #' @description Estimation of the \eqn{\Sigma} in the multivariate diffusion
 #' \deqn{dX_t=b(X_t)dt+\Sigma dW_t}{dX_t=b(X_t)dt+\Sigma dW_t}
-#' by the high-frequency estimate
-#' \deqn{\hat\Sigma = \frac{1}{N\Delta}\sum_{i=1}^N(X_i-X_{i-1})(X_i-X_{i-1})^T}{\hat\Sigma = \frac{1}{N\Delta}\sum_{i=1}^N(X_i-X_{i-1})(X_i-X_{i-1})^T.}
+#' by the high-frequency estimate \deqn{
+#' \hat\Sigma = \frac{1}{N\Delta}\sum_{i=1}^N(X_i-X_{i-1})(X_i-X_{i-1})^T}{
+#' \hat\Sigma = \frac{1}{N\Delta}\sum_{i=1}^N(X_i-X_{i-1})(X_i-X_{i-1})^T.}
 #'
-#' @param data vector or matrix of size \code{c(N, p)} containing the discretized process.
+#' @param data vector or matrix of size \code{c(N, p)} containing the
+#' discretized process.
 #' @param delta discretization step.
 #' @param circular whether the process is circular or not.
-#' @param diagonal,isotropic enforce different constraints for the diffusion matrix.
+#' @param diagonal,isotropic enforce different constraints for the diffusion
+#' matrix.
 #' @return The estimated diffusion matrix of size \code{c(p, p)}.
 #' @details See Section 3.1 in García-Portugués et al. (2019) for details.
 #' @references
-#' García-Portugués, E., Sørensen, M., Mardia, K. V. and Hamelryck, T. (2019) Langevin diffusions on the torus: estimation and applications. \emph{Statistics and Computing}, 29(2):1--22. \doi{10.1007/s11222-017-9790-2}
+#' García-Portugués, E., Sørensen, M., Mardia, K. V. and Hamelryck, T. (2019)
+#' Langevin diffusions on the torus: estimation and applications.
+#' \emph{Statistics and Computing}, 29(2):1--22. \doi{10.1007/s11222-017-9790-2}
 #' @examples
 #' # 1D
 #' x <- drop(euler1D(x0 = 0, alpha = 1, mu = 0, sigma = 1, N = 1000,
@@ -375,9 +401,12 @@ sigmaDiff <- function(data, delta, circular = TRUE, diagonal = FALSE,
 }
 
 
-#' @title Approximate MLE of the WN diffusion in 2D from a sample of initial and final pairs of angles.
+#' @title Approximate MLE of the WN diffusion in 2D from a sample of initial
+#' and final pairs of angles.
 #'
-#' @description Approximate Maximum Likelihood Estimation (MLE) for the Wrapped Normal (WN) diffusion, using the wrapped Ornstein--Uhlenbeck diffusion and assuming initial stationarity.
+#' @description Approximate Maximum Likelihood Estimation (MLE) for the Wrapped
+#' Normal (WN) diffusion, using the wrapped Ornstein--Uhlenbeck diffusion and
+#' assuming initial stationarity.
 #'
 #' @inheritParams logLikWouPairs
 #' @inheritParams approxMleWn2D
@@ -402,11 +431,12 @@ sigmaDiff <- function(data, delta, circular = TRUE, diagonal = FALSE,
 approxMleWnPairs <- function(data, delta, start = c(0, 0, 1, 1, 0, 1, 1),
                              alpha = rep(NA, 3), mu = rep(NA, 2),
                              sigma = rep(NA, 2), rho = NA,
-                             lower = c(-pi, -pi, 0.01, 0.01, -25, 0.01, 0.01, -0.99),
+                             lower = c(-pi, -pi, 0.01, 0.01, -25, 0.01, 0.01,
+                                       -0.99),
                              upper = c(pi, pi, 25, 25, 25, 25, 25, 0.99),
                              maxK = 2, expTrc = 30, ...) {
 
-  # Specfied parameters
+  # Specified parameters
   specPars <- c(alpha, mu, sigma, rho)
   indUnSpecPars <- is.na(specPars)
 
