@@ -32,7 +32,7 @@ arma::mat forwardSweepPeriodicTridiag(arma::vec a, arma::vec b, arma::vec c);
 //'
 //' If \code{imposePositive = TRUE}, the code implicitly assumes that the solution integrates to one at any step. This might b unrealistic if the initial condition is not properly represented in the grid (for example, highly concentrated density in a sparse grid).
 //' @references
-//' Thomas, J. W. (1995). \emph{Numerical Partial Differential Equations: Finite Difference Methods}. Springer, New York. \url{https://doi.org/10.1007/978-1-4899-7278-1}
+//' Thomas, J. W. (1995). \emph{Numerical Partial Differential Equations: Finite Difference Methods}. Springer, New York. \doi{10.1007/978-1-4899-7278-1}
 //' @examples
 //' # Parameters
 //' Mx <- 200
@@ -144,7 +144,7 @@ arma::mat crankNicolson1D(arma::mat u0, arma::vec b, arma::vec sigma2, arma::uve
         arma::uword j = ind(i);
         double m = minU(j);
         u.col(j) -= m;
-        u.col(j) /= (1 - m * 2 * PI);
+        u.col(j) /= (1 - m * 2 * M_PI);
 
       }
 
@@ -187,7 +187,7 @@ arma::mat crankNicolson1D(arma::mat u0, arma::vec b, arma::vec sigma2, arma::uve
         arma::uword j = ind(i);
         double m = minU(j);
         u0.col(j) -= m;
-        u0.col(j) /= (1 - m * 2 * PI);
+        u0.col(j) /= (1 - m * 2 * M_PI);
 
       }
 
@@ -227,7 +227,7 @@ arma::mat crankNicolson1D(arma::mat u0, arma::vec b, arma::vec sigma2, arma::uve
 //'
 //' If \code{imposePositive = TRUE}, the code implicitly assumes that the solution integrates to one at any step. This might b unrealistic if the initial condition is not properly represented in the grid (for example, highly concentrated density in a sparse grid).
 //' @references
-//' Thomas, J. W. (1995). \emph{Numerical Partial Differential Equations: Finite Difference Methods}. Springer, New York. \url{https://doi.org/10.1007/978-1-4899-7278-1}
+//' Thomas, J. W. (1995). \emph{Numerical Partial Differential Equations: Finite Difference Methods}. Springer, New York. \doi{10.1007/978-1-4899-7278-1}
 //' @examples
 //' # Parameters
 //' Mx <- 100
@@ -441,7 +441,7 @@ arma::mat crankNicolson2D(arma::mat u0, arma::mat bx, arma::mat by, arma::mat si
         arma::uword j = ind(i);
         double m = minU(j);
         u.col(j) -= m;
-        u.col(j) /= (1 - m * 4 * PI * PI);
+        u.col(j) /= (1 - m * 4 * M_PI * M_PI);
 
       }
 
@@ -517,7 +517,7 @@ arma::mat crankNicolson2D(arma::mat u0, arma::mat bx, arma::mat by, arma::mat si
         arma::uword j = ind(i);
         double m = minU(j);
         u0.col(j) -= m;
-        u0.col(j) /= (1 - m * 4 * PI * PI);
+        u0.col(j) /= (1 - m * 4 * M_PI * M_PI);
 
       }
 
